// --------------------------------- lsw_defintions.h -------------------------------------------
//
//  Include file for Linux LabBrick rf switch defintions
//
// (c) 2020-2021 by Vaunix Technology Corporation, all rights reserved
//
//  JA  Version 1.0 LSW Ethernet Driver Interface Definitions
//-----------------------------------------------------------------------------
#ifndef __LSWDRVR_H__
#define __LSWDRVR_H__

/// ---------- Include headers ----------------

//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif


/// ---------- Macros ----------------
#define MAX_MODELNAME   32
#define MAX_SWVERSION   6
#define MAX_NETBUFF     16
#define MAX_SWDEVICES   12

// STATUS ENUM
typedef enum
{
    STATUS_OK,          // 0
    STATUS_ERROR,       // 1
    MAX_STATUS_REPORT
}STATUS_REPORT_T;

// Hardware type values by device name (used in lda[DeviceId].DevType)
typedef enum
{
    LSW_802_P4T=1,      // 1
    MAX_LSW_DEVICEMODELS
}LSW_DEVICE_MODELS_T;

// Switch output port configuration
typedef enum
{
	SW_PORT1=1,
	SW_PORT2,
	SW_PORT3,
	SW_PORT4,
	MAX_SWPORTS
}LSW_SWPORT_T;

// LSW Device Response Data Structure
typedef struct
{
  //  Global device variables
  int serialnumber;
  char modelname[MAX_MODELNAME];
  char swversion[MAX_SWVERSION];
  int ipmode;
  char ipaddress[MAX_NETBUFF];
  char netmask[MAX_NETBUFF];
  char gateway[MAX_NETBUFF];
  int maxswitchdevices;
  int rfswitchoutput[MAX_SWDEVICES];                  // the current channel number
} LSWDEVICE_DATA_T;

// LSW Device Init
void fnLSW_Init(void);

// LSW Test mode
void fnLSW_SetTestMode(bool testmode);

// InitDevice
STATUS_REPORT_T fnLSW_InitDevice(char* deviceip);

// Close the Device Socket
STATUS_REPORT_T fnLSW_CloseDevice(char* deviceip);

// Device Ready
STATUS_REPORT_T fnLSW_CheckDeviceReady(char* deviceip);

// Get Model Name
STATUS_REPORT_T fnLSW_GetModelName(char* deviceip, char *respdata);

// Get Serial Number of the device
STATUS_REPORT_T fnLSW_GetSerialNumber(char* deviceip, int* respdata);

// Get SW Version of the device
STATUS_REPORT_T fnLSW_GetSoftwareVersion(char* deviceip, char* respdata);

// Get IP Mode of the device  0 - Static, 1 - DHCP
STATUS_REPORT_T fnLSW_GetIPMode(char* deviceip, int* respdata);

// Get IP Address of the device
STATUS_REPORT_T fnLSW_GetIPAddress(char* deviceip, char* respdata);

// Get Netmask of the device
STATUS_REPORT_T fnLSW_GetNetmask(char* deviceip, char* respdata);

// Get Gateway of the device
STATUS_REPORT_T fnLSW_GetGateway(char* deviceip, char* respdata);

// Get Max Switch Devices
STATUS_REPORT_T fnLSW_GetMaxSwitchDevices(char* deviceip,int* respdata);

// Get Switch RF output state [Index range from 1 - 12]
STATUS_REPORT_T fnLSW_GetSwitchRFoutput(char* deviceip, int swindex, int* respdata);

// Set Switch RF output state [Index range from 1 - 12]
STATUS_REPORT_T fnLSW_SetSwitchRFoutput(char* deviceip, int swindex, LSW_SWPORT_T swport);

// Save Setting Callback
STATUS_REPORT_T fnLSW_SaveSettings(char* deviceip);

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif // __LSWDRVR_H__
